==> exo.platform.packaging.source-3.0.10.zip: exo-gwtframework-parent-1.0.8/exo-gwtframework-editor/src/main/java/org/exoplatform/gwtframework/editor/api/TextEditor.java <==
/**
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.exoplatform.gwtframework.editor.api;

import java.util.List;



/**
 * Created by The eXo Platform SAS .
 * 
 * @author <a href="mailto:gavrikvetal@gmail.com">Vitaliy Gulyy</a>
 * @version $
 */

public interface TextEditor
{
   /**
    * @return unique identifier which can be used to found out editor instance in the DOM
    */
   String getEditorId();

   /**
    * @return content of editor
    */
   String getText();

   /**
    * replace current content of editor by text parameter
    * @param text - new editor content
    */
   void setText(String text);
   
   /**
    * @return <b>true</b> if editor supports code indentation
    */
   boolean canFormatSource();
   /**
    * indents code according to content type
    */
   void formatSource();

   
   /**
    * @return <b>true</b> if editor supports line numbering that is displaying line numbers at the left field of code
    */
   boolean canSetLineNumbers();
   /** 
    * Displays line numbers if showLineNumbers = true, or hides otherwise
    * @param showLineNumbers 
    */
   void setLineNumbers(boolean showLineNumbers);

   /**
    * sets text cursor into the editor area
    */  
   void setFocus();

   boolean canGoToLine();    
   void goToLine(int lineNumber);

   boolean canDeleteCurrentLine();    
   void deleteCurrentLine();
   
   boolean canFindAndReplace();
   boolean findAndSelect(String find, boolean caseSensitive);
   void replaceFoundedText(String find, String replace, boolean caseSensitive);   
   
   
   /**
    * @return <b>true</b> if there are any changes which can be undo in editor
    */
   boolean hasUndoChanges();

   /**
    * undo latest change of content
    */
   void undo();

   /**
    * @return <b>true</b> if there are any changes which can be redo in editor.
    */
   boolean hasRedoChanges();

   /**
    * redo latest change of content
    */
   void redo();

   /**
    * @return <b>true</b> if content set as read-only earlier
    */
   boolean isReadOnly();

   /**
    * denies changing of content if readOnly = true
    * @param readOnly
    */
   void setReadOnly(boolean readOnly);
   
   int getCursorRow();
   int getCursorCol();  
   
   void setHotKeyList(List<String> hotKeyList);
   
   public boolean canCreateTokenList();   
   List<Token> getTokenList();
}

==> exo.platform.packaging.source-3.5.5.zip: exo-gwtframework-parent-1.1.2/exo-gwtframework-editor/src/main/java/org/exoplatform/gwtframework/editor/api/TextEditor.java <==
/**
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.exoplatform.gwtframework.editor.api;

import java.util.List;



/**
 * Created by The eXo Platform SAS .
 * 
 * @author <a href="mailto:gavrikvetal@gmail.com">Vitaliy Gulyy</a>
 * @version $
 */

public interface TextEditor
{
   /**
    * @return unique identifier which can be used to found out editor instance in the DOM
    */
   String getEditorId();

   /**
    * @return content of editor
    */
   String getText();

   /**
    * replace current content of editor by text parameter
    * @param text - new editor content
    */
   void setText(String text);
   
   /**
    * @return <b>true</b> if editor supports code indentation
    */
   boolean canFormatSource();
   /**
    * indents code according to content type
    */
   void formatSource();

   
   /**
    * @return <b>true</b> if editor supports line numbering that is displaying line numbers at the left field of code
    */
   boolean canSetLineNumbers();
   /** 
    * Displays line numbers if showLineNumbers = true, or hides otherwise
    * @param showLineNumbers 
    */
   void setLineNumbers(boolean showLineNumbers);

   /**
    * sets text cursor into the editor area
    */  
   void setFocus();

   /**
    * @return return <b>true</b> if you can use method goToLine() or goToPosition() to set cursor in the any position in the current editor 
    */
   boolean canGoToLine();   
   
   /**
    * @param lineNumber
    * @return <b>true</b> if you can use method goToLine() or goToPosition() to set cursor in the line with lineNumber in the current editor
    */
   boolean canGoToLine(int lineNumber);    

   void goToLine(int lineNumber);

   /**
    * Set cursor at the position (row, column). If there are now such row or column in the specified row in the text, then cursor will be stayed as it. 
    * @param column
    * @param row
    */
   void goToPosition(int row, int column);
   
   boolean canDeleteCurrentLine();    
   void deleteCurrentLine();
   
   boolean canFindAndReplace();
   boolean findAndSelect(String find, boolean caseSensitive);
   void replaceFoundedText(String find, String replace, boolean caseSensitive);   
   
   
   /**
    * @return <b>true</b> if there are any changes which can be undo in editor
    */
   boolean hasUndoChanges();

   /**
    * undo latest change of content
    */
   void undo();

   /**
    * @return <b>true</b> if there are any changes which can be redo in editor.
    */
   boolean hasRedoChanges();

   /**
    * redo latest change of content
    */
   void redo();

   /**
    * @return <b>true</b> if content is read-only
    */
   boolean isReadOnly();
   
   int getCursorRow();
   int getCursorCol();  
   
   void setHotKeyList(List<String> hotKeyList);
   
   public boolean canCreateTokenList();   
   List<Token> getTokenList();
}
